==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QTextFrame_iterator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QTextFrame>
#include <QtCore/QVariant>
#include <QtGui/qtextobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextFrame_iterator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextFrame::iterator")
    QTextFrame::iterator *_ptr = reinterpret_cast<QTextFrame::iterator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new iterator()
void __qt_construct_QTextFrame_iterator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct iterator()")
    Q_UNUSED(__java_arguments)
    QTextFrame::iterator *__qt_this = new(__qtjambi_ptr) QTextFrame::iterator();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTextFrame::iterator::iterator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_initialize_1native__Lio_qt_gui_QTextFrame_00024iterator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextFrame::iterator::iterator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextFrame_iterator, sizeof(QTextFrame::iterator), typeid(QTextFrame::iterator), false, &deleter_QTextFrame_iterator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new iterator(QTextFrame::iterator)
void __qt_construct_QTextFrame_iterator_cref_QTextFrame_iterator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct iterator(QTextFrame::iterator)")
    jobject o0 = __java_arguments[0].l;
    const QTextFrame::iterator& __qt_o0 = qtjambi_cast<const QTextFrame::iterator& >(__jni_env, o0);
    QTextFrame::iterator *__qt_this = new(__qtjambi_ptr) QTextFrame::iterator(__qt_o0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextFrame::iterator::iterator(QTextFrame::iterator)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_initialize_1native__Lio_qt_gui_QTextFrame_00024iterator_2Lio_qt_gui_QTextFrame_00024iterator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject o0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextFrame::iterator::iterator(QTextFrame::iterator)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = o0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextFrame_iterator_cref_QTextFrame_iterator, sizeof(QTextFrame::iterator), typeid(QTextFrame::iterator), false, &deleter_QTextFrame_iterator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextFrame::iterator
void __qt_destruct_QTextFrame_iterator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextFrame::iterator")
    reinterpret_cast<QTextFrame::iterator*>(ptr)->~iterator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextFrame::iterator::atEnd()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_atEnd_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::atEnd()const", __qt_this)
        __java_return_value = __qt_this->atEnd();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::currentBlock()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_currentBlock_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::currentBlock()const", __qt_this)
        QTextBlock __qt_return_value = __qt_this->currentBlock();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::currentFrame()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_currentFrame_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::currentFrame()const", __qt_this)
        QTextFrame* __qt_return_value = __qt_this->currentFrame();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::operator++()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::operator++()", __qt_this)
        QTextFrame::iterator& __qt_return_value = ++(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextFrame::iterator::operator--()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_previous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::operator--()", __qt_this)
        QTextFrame::iterator& __qt_return_value = --(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextFrame::iterator::operator==(QTextFrame::iterator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_equals_1native_1cref_1QTextFrame_1iterator_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID o0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::operator==(QTextFrame::iterator)const", __qt_this)
        const QTextFrame::iterator& __qt_o0 = QtJambiAPI::valueReferenceFromNativeId<QTextFrame::iterator>(o0);
        __java_return_value = (*__qt_this) == __qt_o0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::parentFrame()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_parentFrame_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::parentFrame()const", __qt_this)
        QTextFrame* __qt_return_value = __qt_this->parentFrame();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextFrame_iterator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextFrame::iterator>("QTextFrame::iterator", "io/qt/gui/QTextFrame$iterator");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextFrame_iterator, {
        ConstructorInfo(&__qt_construct_QTextFrame_iterator, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextFrame_iterator_cref_QTextFrame_iterator, "Lio/qt/gui/QTextFrame$iterator;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextFrame_iterator);
    registerMetaType<QTextFrame::iterator>("QTextFrame::iterator");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QTextFrame_iterator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QTextFrame>
#include <QtCore/QVariant>
#include <QtGui/qtextobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextFrame_iterator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextFrame::iterator")
    QTextFrame::iterator *_ptr = reinterpret_cast<QTextFrame::iterator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new iterator()
void __qt_construct_QTextFrame_iterator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct iterator()")
    Q_UNUSED(__java_arguments)
    QTextFrame::iterator *__qt_this = new(__qtjambi_ptr) QTextFrame::iterator();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QTextFrame::iterator::iterator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_initialize_1native__Lio_qt_gui_QTextFrame_00024iterator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextFrame::iterator::iterator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextFrame_iterator, sizeof(QTextFrame::iterator), typeid(QTextFrame::iterator), 0, false, &deleter_QTextFrame_iterator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new iterator(QTextFrame::iterator)
void __qt_construct_QTextFrame_iterator_cref_QTextFrame_iterator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct iterator(QTextFrame::iterator)")
    jobject other0 = __java_arguments[0].l;
    const QTextFrame::iterator& __qt_other0 = qtjambi_cast<const QTextFrame::iterator&>(__jni_env, other0);
    QTextFrame::iterator *__qt_this = new(__qtjambi_ptr) QTextFrame::iterator(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QTextFrame::iterator::iterator(QTextFrame::iterator)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_initialize_1native__Lio_qt_gui_QTextFrame_00024iterator_2Lio_qt_gui_QTextFrame_00024iterator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextFrame::iterator::iterator(QTextFrame::iterator)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextFrame_iterator_cref_QTextFrame_iterator, sizeof(QTextFrame::iterator), typeid(QTextFrame::iterator), 0, false, &deleter_QTextFrame_iterator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextFrame::iterator
void __qt_destruct_QTextFrame_iterator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextFrame::iterator")
    reinterpret_cast<QTextFrame::iterator*>(ptr)->~iterator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextFrame::iterator::atEnd()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_atEnd_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::atEnd()const", __this_nativeId)
        __java_return_value = __qt_this->atEnd();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::currentBlock()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_currentBlock_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::currentBlock()const", __this_nativeId)
        QTextBlock __qt_return_value = __qt_this->currentBlock();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::currentFrame()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_currentFrame_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::currentFrame()const", __this_nativeId)
        QTextFrame* __qt_return_value = __qt_this->currentFrame();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::operator++()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::operator++()", __this_nativeId)
        QTextFrame::iterator& __qt_return_value = ++(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextFrame::iterator::operator--()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_previous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::operator--()", __this_nativeId)
        QTextFrame::iterator& __qt_return_value = --(*__qt_this);
        Q_UNUSED(__qt_return_value)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextFrame::iterator::operator==(QTextFrame::iterator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_equals_1native_1cref_1QTextFrame_1iterator_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID o0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::operator==(QTextFrame::iterator)const", __this_nativeId)
        const QTextFrame::iterator& __qt_o0 = QtJambiAPI::valueReferenceFromNativeId<QTextFrame::iterator>(o0);
        __java_return_value = (*__qt_this) == __qt_o0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextFrame::iterator::parentFrame()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_parentFrame_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextFrame::iterator::parentFrame()const", __this_nativeId)
        QTextFrame* __qt_return_value = __qt_this->parentFrame();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextFrame_00024iterator_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextFrame::iterator *__qt_this = QtJambiAPI::objectFromNativeId<QTextFrame::iterator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextFrame_iterator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextFrame::iterator>("QTextFrame::iterator", "io/qt/gui/QTextFrame$iterator");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QTextFrame_iterator, {
        ConstructorInfo(&__qt_construct_QTextFrame_iterator, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextFrame_iterator_cref_QTextFrame_iterator, "Lio/qt/gui/QTextFrame$iterator;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextFrame_iterator);
    registerMetaType<QTextFrame::iterator>("QTextFrame::iterator");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
